@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2005-2014                                               *
+ *   copyright (C) 2005-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -172,7 +172,7 @@ UMLObject* findUMLObject(QString name, UMLObject::ObjectType type)
  * @param comment comment for uml object
  * @param stereotype stereotype for uml object
  * @param searchInParentPackageOnly flags to search only in parent package
- * @param remapParent flag to control remapping of parents if an uml object has been found
+ * @param remapParent flag to control remapping of parents if a uml object has been found
  * @return new object or zero
  */
 UMLObject *createUMLObject(UMLObject::ObjectType type,
@@ -365,15 +365,15 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
 /**
  * Create hierachical tree of UML objects
  *
- * This methods creates the UML object specified by #type and #name including an optional namespace hierachy
+ * This method creates the UML object specified by #type and #name including an optional namespace hierarchy
  * if included in the #name e.g. NamespaceA::ClassA in C++.
  *
  * @param type  type of UML object to create
  * @param name  name of UML object
- * @param topLevelParent  UML package to add the hierachie of UML objects
+ * @param topLevelParent  UML package to add the hierarchy of UML objects
  * @return pointer to created or found UML object
  */
-UMLObject* createUMLObjectHierachy(UMLObject::ObjectType type, const QString &name, UMLPackage *topLevelParent)
+UMLObject* createUMLObjectHierarchy(UMLObject::ObjectType type, const QString &name, UMLPackage *topLevelParent)
 {
     UMLPackage *parent = topLevelParent;
     QString objectName;
@@ -482,7 +482,7 @@ UMLAttribute *insertAttribute(UMLClassifier *owner, Uml::Visibility::Enum scope,
   * @param klass          The classifier into which the operation shall be added.
   * @param op             Reference to pointer to the temporary UMLOperation
   *                       for insertion.  The caller relinquishes ownership of the
-  *                       object pointed to.  If an UMLOperation of same signature
+  *                       object pointed to.  If a UMLOperation of same signature
   *                       already exists  at the classifier then the incoming
   *                       UMLOperation is deleted and the pointer is set to the
   *                       existing UMLOperation.
@@ -588,7 +588,7 @@ UMLAttribute* addMethodParameter(UMLOperation *method,
 }
 
 /**
- * Add an enum literal to an UMLEnum.
+ * Add an enum literal to a UMLEnum.
  */
 void addEnumLiteral(UMLEnum *enumType, const QString &literal, const QString &comment, const QString &value)
 {
@@ -737,28 +737,33 @@ void createGeneralization(UMLClassifier *child, const QString &parentName)
  */
 UMLEnum *remapUMLEnum(UMLObject *ns, UMLPackage *currentScope)
 {
-    if (ns) {
-        QString comment = ns->doc();
-        QString name = ns->name();
-        QString stereotype = ns->stereotype();
-        Uml::Visibility::Enum visibility = ns->visibility();
-        UMLApp::app()->document()->removeUMLObject(ns, true);
-        if (currentScope == 0)
-            currentScope = UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical);
-        UMLObject *o = Object_Factory::createNewUMLObject(UMLObject::ot_Enum, name, currentScope, false);
-        if (!o)
-            return 0;
-        UMLEnum *e = o->asUMLEnum();
-        if (!e)
-            return 0;
-        e->setDoc(comment);
-        e->setStereotypeCmd(stereotype.isEmpty() ? QLatin1String("enum") : stereotype);
-        e->setVisibilityCmd(visibility);
-        // add to parents child list
-        if (!currentScope->containedObjects().contains(e))
-            currentScope->containedObjects().append(e);
-        return e;
+    if (ns == 0) {
+        return 0;
     }
+    QString comment = ns->doc();
+    QString name = ns->name();
+    QString stereotype = ns->stereotype();
+    Uml::Visibility::Enum visibility = ns->visibility();
+    UMLApp::app()->document()->removeUMLObject(ns, true);
+    if (currentScope == 0)
+        currentScope = UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical);
+    UMLObject *o = Object_Factory::createNewUMLObject(UMLObject::ot_Enum, name, currentScope, false);
+    if (!o) {
+        DEBUG(DBG_SRC) << name << " : Object_Factory::createNewUMLObject(ot_Enum) returns null";
+        return 0;
+    }
+    UMLEnum *e = o->asUMLEnum();
+    if (!e) {
+        DEBUG(DBG_SRC) << name << " : object returned by Object_Factory::createNewUMLObject is not Enum";
+        return 0;
+    }
+    e->setDoc(comment);
+    e->setStereotypeCmd(stereotype.isEmpty() ? QLatin1String("enum") : stereotype);
+    e->setVisibilityCmd(visibility);
+    // add to parents child list
+    if (currentScope->addObject(e, false))  // false => non interactively
+        return e;
+    DEBUG(DBG_SRC) << name << " : name is already present in " << currentScope->name();
     return 0;
 }
 
