@@ -4,19 +4,19 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
 #ifndef ACTIVITYDIALOG_H
 #define ACTIVITYDIALOG_H
 
-#include <dialogbase.h>
+#include <multipagedialogbase.h>
 
 //forward declarations
 class ActivityWidget;
+class DocumentationWidget;
 class KLineEdit;
-class KTextEdit;
 class QLabel;
 class QGroupBox;
 class QRadioButton;
@@ -26,9 +26,9 @@ class UMLView;
  * Displays the properties for a @ref ActivityWidget
  *
  * @author   Paul Hensgen
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
-class ActivityDialog : public DialogBase
+class ActivityDialog : public MultiPageDialogBase
 {
     Q_OBJECT
 public:
@@ -59,9 +59,9 @@ protected:
     struct GeneralPageWidgets {
         QLabel * nameL, * typeL, * preL, * postL;
         KLineEdit * nameLE, * typeLE, * preLE, * postLE;
-        KTextEdit * docTE;
+        DocumentationWidget *docWidget;
         QRadioButton * NormalRB, * ParamRB, * InvokRB; // this is to implement the parameter node activity or an invok action
-        QGroupBox * docGB, * generalGB;
+        QGroupBox * generalGB;
     }
     m_GenPageWidgets;
 
