@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
+ *   copyright (C) 2006-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -21,7 +21,7 @@
 class KUrl;
 
 /**
- * Exports an UMLView in various image formats.
+ * Exports a UMLView in various image formats.
  * It can also export all the views in the current document.
  *
  * The methods in this class don't communicate with the user, so asking the format
@@ -40,7 +40,7 @@ public:
     static QString imageTypeToMimeType(const QString& imageType);
     static QString mimeTypeToImageType(const QString& mimeType);
 
-    UMLViewImageExporterModel(float resolution = 0.0);
+    explicit UMLViewImageExporterModel(float resolution = 0.0);
     virtual ~UMLViewImageExporterModel();
 #if QT_VERSION >= 0x050000
     QString exportView(UMLScene* scene, const QString &imageType, const QUrl &url) const;
